@@ -3,14 +3,12 @@ from datetime import datetime
 from django.core import management
 from celery import Celery
 import os
-from django.conf import settings
-from django.utils.text import slugify
 
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
-app = Celery(slugify(settings.SITE_NAME))
+app = Celery('webspace.bakery')
 app.config_from_object('webspace.bakery.celeryconfig', namespace='CELERY')
-app.autodiscover_tasks()
 app.control.purge()
+app.autodiscover_tasks()
 
 
 @app.task(bind=True)
